require 'spec_helper'
require 'derketo/event_trace'

describe Derketo::EventTrace do
  let(:trace) { Derketo::EventTrace.new }
  let(:node) { Node.new }

  describe '#push' do
    it 'adds the first event to the trace' do
      trace.push(node)
      expect(trace.first).to eq(node)
    end

    it 'adds two events to the trace' do
      trace.push(node)
      new_node = Node.new
      trace.push(new_node)
      expect(trace.first).to_not eq(new_node)
    end

    it 'sets the event\'s previous link' do
      trace.push(node)
      new_node = Node.new
      trace.push(new_node)
      expect(new_node.previous).to eq(node)
    end
  end

  describe '#last' do
    it 'returns the first event if there is only one' do
      trace.push(node)
      expect(trace.last).to eq(node)
    end

    it 'returns the last event if there is more than one' do
      trace.push(node)
      new_node = Node.new
      trace.push(new_node)
      expect(trace.last).to eq(new_node)
    end
  end

  describe '#all' do
    it 'returns an empty array if there are no events' do
      expect(trace.all).to eq([])
    end

    it 'returns an array with one element if there is one event' do
      trace.push(node)
      expect(trace.all).to eq([node])
    end

    it 'returns an array with multiple elements when there are multiple events' do
      trace.push(node)
      new_node = Node.new
      trace.push(new_node)
      expect(trace.all.count).to eq(2)
    end
  end
end
